#Statistical Analysis of Hard Parts data for Lyssikatos & Wenzel 2022
#Import data set 'allmeta_prey_v5.csv' from ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1
#It was produced in SAS ~/seasamp/biosamp/PvHg_summary_v2.sas

####################
## Load libraries ##
####################

library(dplyr); library(tidyr); library(boot); library(mgcv); library(lme4); library(AER); library(ggplot2)

rm(list=ls(all=TRUE))

## Set Working Directory ##
setwd('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')


######################
## Read in datasets ##
######################

#version 5#
#The format is detail prey species, so all meta data is repeated for each Tagnum
#Includes both Pv and Hg stomach samples

obs = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/allmeta_prey_v5.csv',header=TRUE)

table(obs$guild)
table(obs$Species)
table(obs$tripid)

mack = obs %>% filter (Species== "Scomber scombrus")
haddock = obs %>% filter (Species== "Melanogrammus aeglefinus")

#obs$epu = factor(obs$epu,levels=c('gb','gom','mab','ss'))

#Remove records with missing effort #SCHAVEZ
#obs = obs %>% filter(!is.na(dysfish))

##################################################
## Aggregate data ##
##################################################

#First eliminate records where guild = junk (i.e. Menidia menidia), empty, and Elasmob
#because they don't contribute to mni or kgs consumed

fix = obs %>% filter (guild != "Junk" & guild !="Elasmob" & guild !="Empty" & guild !="Benth/Piscv")
fix$guild <- droplevels(fix$guild)
dim(obs)
dim(fix)
table(obs$guild)
table(fix$guild)

table(fix$guild,fix$comname)

##

#Horizontal boxplots of MNI & KGS by various factors

library(tidyr) 
library(ggplot2)
df=as.data.frame(fix) #detail prey species records by stomach samples

plot.new()
library(viridis)
#h_line=0.033

  #MNI boxplots
  ggplot(data=df[df$sex!=".",], aes(x=mni, y=Species, fill=comname)) +
  geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname), show.legend=FALSE) +
  facet_grid(cols=vars(sex), scale="free") +
  scale_fill_viridis(discrete = TRUE, alpha=0.6) +
  geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
  theme_light() +
  theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
#+ geom_hline(aes(yintercept=h_line))
  
  #KGS boxplots
  ggplot(data=df[df$sex!=".",], aes(x=wgtkg, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname)) +
    facet_grid(cols=vars(sex), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank())
  
  #MNI boxplots by age groups
  ggplot(data=df[df$age!="unk",], aes(x=mni, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname), show.legend=FALSE) +
    facet_grid(cols=vars(age), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
  #+ geom_hline(aes(yintercept=h_line))
  
  #KGS boxplots by age groups
  ggplot(data=df[df$age!="unk",], aes(x=wgtkg, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname)) +
    facet_grid(cols=vars(age), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank())

  #MNI boxplots by area groups
  ggplot(data=df[df$Epu!="",], aes(x=mni, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname), show.legend=FALSE) +
    facet_grid(cols=vars(Epu), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
  #+ geom_hline(aes(yintercept=h_line))
  
  #KGS boxplots by area groups
  ggplot(data=df[df$Epu!="",], aes(x=wgtkg, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname)) +
    facet_grid(cols=vars(Epu), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
  #ggsave(plot=q, width = 7, height = 10, dpi=300, filename = "testsize_r.pdf")

  #MNI boxplots by season groups
  #Re-Order seasons so they plot across a squential calendar
  df$season<-ordered(df$season, levels = c("winter","spring","summer","fall"))
  
  ggplot(data=df[df$season!="",], aes(x=mni, y=Species, fill=comname)) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname), show.legend=FALSE) +
    facet_grid(cols=vars(season), scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
  #+ geom_hline(aes(yintercept=h_line))
  
  #KGS boxplots by season groups
    ggplot(data=df[df$season!="",], aes(x=wgtkg, y=Species, fill=comname)) + #, plot=0) +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(colour=comname)) +
    facet_grid(cols=vars(season)) + #, scale="free") +
    scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
  
  #ggsave(plot=q, width = 7, height = 10, dpi=300, filename = "testsize_r.pdf")
  
  #PLot mean mni and kgs by different factors and predator
    
library(tidyr) 
library(ggplot2)

    df2 = df %>% group_by(comname,sex,Species) %>%
      summarise(
        N_stomachs = n(),
        x_mni = (mean(mni)),
        x_kgs = (mean(wgtkg)),
        sd_mni = (sd(mni)),
        sd_kgs = (sd(wgtkg))
      )
    
ggplot(data=df2[df2$sex!=".",], aes(x=x_mni, y=Species, fill=comname)) +
  facet_grid(cols=vars(sex), scale="free") +
  geom_bar(stat="identity", color="black",
        position=position_dodge()) +
  geom_errorbar(aes(xmin=x_mni-sd_mni, xmax=x_mni+sd_mni), width=.2,
                position=position_dodge(.9))

#Median and quartiles

df3 = df %>% group_by(comname,sex,Species) %>%
  summarise(
    N_stomachs = n(),
    md_mni = (median(mni)),
    md_kgs = (median(wgtkg))
    #sd_mni = ((mni)),
    #sd_kgs = (sd(wgtkg))
  )
#Re-Order on sex then comname
names(df3)
df3<-as.data.frame(df3)

df3[
  order(df3[,2],df3[,1]),
  ]

plot.new()

#df3<-df2[df2$sex=="F",]  

ggplot(data=df3[df3$sex!=".",], aes(x=md_mni, y=Species, fill=comname)) +
  scale_fill_manual(values=c("grey", "brown")) +
  facet_grid(cols=vars(sex,comname)) + #, scale="free") +
  geom_bar(stat="identity", color="black", show.legend = FALSE) +
  theme_light() +
  theme(axis.text = element_text(size=6), axis.title.x = element_blank(), axis.title.y = element_blank())

#Revised boxplots that show comname on seperate panels, less busy and changes color scheme
#and not showing all the values - just outliers

#MNI boxplots
ggplot(data=df[df$sex!=".",], aes(x=mni, y=Species, fill=comname)) +
  facet_grid(cols=vars(sex,comname), scale="free") +
  geom_boxplot(stat="boxplot", notch=FALSE, aes(color=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
  #scale_fill_viridis(discrete = TRUE, alpha=0.6) +
  #geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
  theme_light() +
  theme(axis.text = element_text(size=6), axis.title.x = element_blank(), axis.title.y = element_blank())

#library(forcats)

Othertl = df %>% filter (guild != "Benthivore")
Benthfig = df %>% filter (guild == "Benthivore")

#Remove mni= 100 haddock in Hg from MAB region - for boxplot

dim(Benthfig)
names(Benthfig)
length(which(Benthfig$mni==100)) #Pv from MAB that has haddock mni=100
length(which(Benthfig[,19]==100)) #does the same as previous line

sub_Benth <- Benthfig[-c(262),]
dim(sub_Benth)

Othertl$guild <- droplevels(Othertl$guild)
Benthfig$guild <-droplevels(Benthfig$guild)
table(Othertl$guild)
table(Benthfig$guild)

##
##MNI by predator & sex - color gray & brown  
  #ggplot(data=Benthfig[Benthfig$sex!=".",], aes(x=mni, y=Species, fill=comname)) +
  #facet_grid(rows=vars(guild),cols=vars(sex,comname), scales="free") +
  #geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
  #scale_fill_manual(values=c("grey", "brown")) +
  #theme_light() +
  #theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank())

## For use in draft MS review with Fred as of 15Nov22
  ## Preferred format:
  
  ggplot(data=Benthfig[Benthfig$sex!=".",], aes(x=wgtkg, y=Species, fill=comname)) +
    facet_grid(rows=vars(guild),cols=vars(sex), scale="free") +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1) + #, show.legend=FALSE) +
    scale_fill_manual(values=c("grey", "brown")) +
    theme_light() +
    theme(legend.position="top", axis.text = element_text(size=8), axis.title.y = element_blank()) 
  
  
    ggplot(data=Othertl[Othertl$sex!=".",], aes(x=wgtkg, y=Species, fill=comname)) +
    facet_grid(rows=vars(guild),cols=vars(sex), scales="free") +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
    scale_fill_manual(values=c("grey", "brown")) +
    theme_light() +
    theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank())
 
    #Benthivores only, 4 x 2 ggplot of season by epu
    ggplot(data=sub_Benth[sub_Benth$Epu!="gb",], aes(x=mni, y=Species, fill=comname)) +
      facet_grid(rows=vars(Epu),cols=vars(season), scale="free") +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1) + #, show.legend=FALSE) +
      scale_fill_manual(values=c("grey", "brown")) +
      theme_light() +
      theme(legend.position="top", axis.text = element_text(size=8), axis.title.y = element_blank()) 
    
    #Benthivores only, 4 x 2 ggplot of season by epu
    ggplot(data=sub_Benth[sub_Benth$sex!=".",], aes(x=mni, y=Species, fill=comname)) +
      facet_grid(rows=vars(sex),cols=vars(age), scale="free") +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1) + #, show.legend=FALSE) +
      scale_fill_manual(values=c("grey", "brown")) +
      theme_light() +
      theme(legend.position="top", axis.text = element_text(size=8), axis.title.y = element_blank()) 
    
    #All Guilds only, 4 x 2 ggplot of sex by age
    df.nomiss.age=df[df$age!="unk",]
    table(df.nomiss.age$age)
    ggplot(data=df[df$sex!=".",], aes(x=mni, y=Species, fill=comname)) +
      facet_grid(rows=vars(sex),cols=vars(age), scale="free") +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
      scale_fill_manual(values=c("grey", "brown")) +
      theme_light() +
      theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) 
    
    
    #All trophic groups, three way ggplot - season, epu, age
    ggplot(data=df[df$Epu!="gb",], aes(x=mni, y=Species, fill=comname)) +
      facet_grid(rows=vars(Epu),cols=vars(season), scale="free") +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
      scale_fill_manual(values=c("grey", "brown")) +
      theme_light() +
      theme(legend.position="top", axis.text = element_text(size=8), axis.title.y = element_blank()) 
    
    
    
    
    #Look at year on x-axis
    
    #First - sum mni and wgtkg by stomach sample retaining meta-data
    
    tagnum_mni_kgs = df %>% group_by(year,comname,Tagnum1,age,sex,Epu,season) %>%
      summarise(
        N_species = n(),
        t_mni = (sum(mni)),
        t_kgs = (sum(wgtkg))
        #sd_mni = ((mni)),
        #sd_kgs = (sd(wgtkg))
      )
    
    #New table of sample sizes among all 4 factors - for manuscript
    newtblv2<-tagnum_mni_kgs[tagnum_mni_kgs$sex!="." & tagnum_mni_kgs$age!="unk",] %>% group_by(comname,age,sex,Epu,season) %>%
      summarise(
        N_stomach = n(),
        md_mni = (median(t_mni)),
        md_kgs = (median(t_kgs)),
        q25_mni = as.numeric(round(quantile(t_mni,probs=0.25))),
        q75_mni = as.numeric(round(quantile(t_mni,probs=0.75))),
        q25_kgs = as.numeric((quantile(t_kgs,probs=0.25))),
        q75_kgs = as.numeric((quantile(t_kgs,probs=0.75))),
      )
     
    #New table of sample sizes among all epu factors - for manuscript
    newtblv2.epu<-tagnum_mni_kgs[tagnum_mni_kgs$sex!="." & tagnum_mni_kgs$age!="unk",] %>% group_by(comname,Epu) %>%
      summarise(
        N_stomach = n(),
        md_mni = (median(t_mni)),
        md_kgs = (median(t_kgs)),
        q25_mni = as.numeric(round(quantile(t_mni,probs=0.25))),
        q75_mni = as.numeric(round(quantile(t_mni,probs=0.75))),
        q25_kgs = as.numeric((quantile(t_kgs,probs=0.25))),
        q75_kgs = as.numeric((quantile(t_kgs,probs=0.75))),
        
      ) 
    
    #New table of sample sizes among all season factors - for manuscript
    newtblv2.season<-tagnum_mni_kgs[tagnum_mni_kgs$sex!="." & tagnum_mni_kgs$age!="unk",] %>% group_by(comname,season) %>%
      summarise(
        N_stomach = n(),
        md_mni = (median(t_mni)),
        md_kgs = (median(t_kgs)),
        q25_mni = as.numeric(round(quantile(t_mni,probs=0.25))),
        q75_mni = as.numeric(round(quantile(t_mni,probs=0.75))),
        q25_kgs = as.numeric((quantile(t_kgs,probs=0.25))),
        q75_kgs = as.numeric((quantile(t_kgs,probs=0.75))),
        
      ) 
    
    #New table of sample sizes among all age factors - for manuscript
    newtblv2.age<-tagnum_mni_kgs[tagnum_mni_kgs$sex!="." & tagnum_mni_kgs$age!="unk",] %>% group_by(comname,age) %>%
      summarise(
        N_stomach = n(),
        md_mni = (median(t_mni)),
        md_kgs = (median(t_kgs)),
        q25_mni = as.numeric(round(quantile(t_mni,probs=0.25))),
        q75_mni = as.numeric(round(quantile(t_mni,probs=0.75))),
        q25_kgs = as.numeric((quantile(t_kgs,probs=0.25))),
        q75_kgs = as.numeric((quantile(t_kgs,probs=0.75))),
        
      ) 
    
    #New table of sample sizes among all sex factors - for manuscript
    newtblv2.sex<-tagnum_mni_kgs[tagnum_mni_kgs$sex!="." & tagnum_mni_kgs$age!="unk",] %>% group_by(comname,sex) %>%
      summarise(
        N_stomach = n(),
        md_mni = (median(t_mni)),
        md_kgs = (median(t_kgs)),
        q25_mni = as.numeric(round(quantile(t_mni,probs=0.25))),
        q75_mni = as.numeric(round(quantile(t_mni,probs=0.75))),
        q25_kgs = as.numeric((quantile(t_kgs,probs=0.25))),
        q75_kgs = as.numeric((quantile(t_kgs,probs=0.75))),
        
      ) 
    #Test transpose function - can't figure out how to transpose more than on value.var, otherwise it works fine
    #t_newtblv2<-dcast(newtblv2,Epu+season+age+sex~comname,value.var="md_mni")
    #t_newtblv2[is.na(t_newtblv2)]<-0
    
    write.csv(newtblv2, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mni_allfct.v2.csv',row.names=FALSE)
    write.csv(newtblv2.epu, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mni_allfct.epu.csv',row.names=FALSE)
    write.csv(newtblv2.season, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mni_allfct.season.csv',row.names=FALSE)
    write.csv(newtblv2.age, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mni_allfct.age.csv',row.names=FALSE)
    write.csv(newtblv2.sex, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mni_allfct.sex.csv',row.names=FALSE)
    
    
    #aggregate(tagnum_mni_kgs$t_kgs, list(tagnum_mni_kgs$comname), FUN=median)
    
    #find outliers
    #dim(df)
    #length(which(df$mni==100)) #Hg from MAB that has haddock mni=100
    #length(which(obs_pred[,18]==87)) #does the same as previous line
    
    #Remove outliers - but first re-run models with truncated dataset (unknowns removed)
    #sub_df <- df[-c(499),]
    #dim(sub_df)
    
    ggplot(data=tagnum_mni_kgs, aes(x=as.factor(year), y=t_kgs, fill=comname)) +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", show.legend=FALSE) +
      #facet_grid(rows=vars(guild), scale="free") + # cols=vars(Epu),
      #scale_y_continuous(limits=c(0,50)) + #outlier.shape=NA,
      scale_y_continuous(breaks=seq(0,20,5)) + #scale_y_continuous(breaks=seq(0,160,20)) +
      scale_fill_manual(values=c("grey", "brown")) +
      theme_light() +
      theme(axis.text = element_text(size=8), axis.title.x = element_blank(), #axis.title.y = element_blank(),
              axis.text.x = element_text(angle=90)) + 
                #geom_hline(yintercept=15, linetype="dashed", color = "darkgray", size=1) +
                #geom_hline(yintercept=21, linetype="dashed", color = "brown", size=1)
                geom_hline(yintercept=1.9, linetype="dashed", color = "darkgray", size=1) +
                geom_hline(yintercept=1.8, linetype="dashed", color = "brown", size=1)
    
    ggplot(data=tagnum_mni_kgs, aes(x=as.factor(year), y=t_kgs, fill=comname)) +
      facet_grid(rows=vars(comname)) +
      scale_y_continuous(breaks=seq(0,20,5)) + #scale_y_continuous(breaks=seq(0,160,20)) +
      scale_fill_manual(values=c("grey", "brown")) +
      #scale_fill_brewer(palette="Dark2") +
      geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
      theme(axis.text = element_text(size=8), axis.title.x = element_blank(), #axis.title.y = element_blank(),
            axis.text.x = element_text(angle=90, vjust=1, hjust=1))
      #geom_hline(yintercept=15, linetype="dashed", color = "darkgray", size=1) +
      #geom_hline(yintercept=21, linetype="dashed", color = "brown", size=1)
    
    
    
    
      #sampe code to add sample size above each year - doesn't work becuase of grouping variables
      #need to put annotate after geom boxplot and move facet_grid to end
      #annotate("text",
               x=1:length(table(df$year)),
               y=aggregate(mni~year, df,median)[ ,2],
               label=table(df$year),
               col="red",
               vjust = -1)

#https://stackoverflow.com/questions/61593052/add-number-of-observations-to-a-multiple-ggplot2-boxplots
  ggplot(data = df.m, aes(x=Species, y=value)) + 
  geom_boxplot(aes(fill=Species))+
  stat_summary(
    fun.data = stat_box_data, 
    geom = "text", 
    hjust = 0.5,
    vjust = 0.9
  ) + 
  facet_wrap( ~ variable, scales="free")
      
      
      #geom_text(data=df %>% group_by(year,comname) %>% summarize(top=max(mni), n=n()), aes(x=year, y=top, label= paste0("n = ", n)))
    
    
#KGS by predator & sex - color gray & brown
  ggplot(data=Benthfig[Benthfig$sex!=".",], aes(x=wgtkg, y=Species, fill=comname)) +
    facet_grid(rows=vars(guild),cols=vars(sex,comname), scales="free") +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
    scale_fill_manual(values=c("grey", "brown")) +
    theme_light() +
    theme(axis.text = element_text(size=6), axis.title.x = element_blank(), axis.title.y = element_blank())
  
  ggplot(data=Othertl[Othertl$sex!=".",], aes(x=wgtkg, y=Species, fill=comname)) +
    facet_grid(rows=vars(guild),cols=vars(sex,comname), scales="free") +
    geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1, show.legend=FALSE) +
    scale_fill_manual(values=c("grey", "brown")) +
    theme_light() +
    theme(axis.text = element_text(size=6), axis.title.x = element_blank(), axis.title.y = element_blank())
  
  
  
  #+ geom_hline(aes(yintercept=h_line))  
  
###################################################
  #Number of unique stomach samples by season & epu

n_unique = fix %>% group_by(comname,season,Epu) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

n_unique_s = fix %>% group_by(comname,season) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

n_unique_a = fix %>% group_by(comname,Epu) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

#Number of unique stomach samples by sex & age

n_unique_sa = fix %>% group_by(comname,sex,age) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

n_unique_sex = fix %>% group_by(comname,sex) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

n_unique_age = fix %>% group_by(comname,age) %>%
  summarise(
    Species = n_distinct(Species),
    samples = n_distinct(Tagnum1)
  )

#The non-stratified Morisita Niche overlap index was caculated in Excel 'Morisita_PvHg_Overlap.xlsx'
#from data written to CSV file 'p_tbl2.csv' then 'p_tbl2_v2.csv' in Allmeta_prey_HgPv.R

#The following prepares the data to generate the Morisita Niche overlap index by season and then by
#area. Not enough samples sizes to do both season & area factors together

#Sum mni and wgtkg by predator, season & prey 
predprey_mni = fix %>% group_by(comname,season,Species) %>%
  summarise(
    mni_tot = as.numeric(round(sum(mni))),
    kgs_tot = (sum(wgtkg))
  )

#Sum mni and wgtkg total by predator & season
pred_mni = predprey_mni %>% group_by(comname,season) %>%
  summarise(
    Tmni = as.numeric(round(sum(mni_tot))),
    Tkgs = (sum(kgs_tot))
  )

#Calculate proportion prey based on mni & kgs - by predator & season
#Output to be used in calculating Proportion of dietary overlap

p_tbl2 = full_join(predprey_mni,pred_mni,by=c('comname','season')) %>%
  ungroup() %>%
  mutate(
    p_prey = (mni_tot / Tmni),
    p_kgs = (kgs_tot / Tkgs)
  )

#Check totals
aggregate(p_tbl2$p_prey, list(p_tbl2$comname,p_tbl2$season), FUN=sum)

#Output p_tbl2 to excel. Fill in rows where only prey consumed by only on predator - needs to have duplicate
#row = where p_prey = 0 for the other predator in order for proportion overlap calculation to be correct
#because it selects minimum p_prey. Also calculate new stats to compute Horisita nich overlap index too.

write.csv(p_tbl2, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_Overlap_season.csv',row.names=FALSE)

# ######### #
# By Sex #
# ######### #

#Sum mni and wgtkg by predator, sex & prey 
predprey_mni = fix %>% group_by(comname,sex,Species) %>%
  summarise(
    mni_tot = as.numeric(round(sum(mni))),
    kgs_tot = (sum(wgtkg))
  )

#Sum mni and wgtkg total by predator & season
pred_mni = predprey_mni %>% group_by(comname,sex) %>%
  summarise(
    Tmni = as.numeric(round(sum(mni_tot))),
    Tkgs = (sum(kgs_tot))
  )

#Calculate proportion prey based on mni & kgs - by predator & sex
#Output to be used in calculating Proportion of dietary overlap

p_tbl2_sex = full_join(predprey_mni,pred_mni,by=c('comname','sex')) %>%
  ungroup() %>%
  mutate(
    p_prey = (mni_tot / Tmni),
    p_kgs = (kgs_tot / Tkgs)
  )

#Check totals
aggregate(p_tbl2_sex$p_prey, list(p_tbl2_sex$comname,p_tbl2_sex$sex), FUN=sum)

#Output p_tbl2 to excel. Fill in rows where prey consumed by only on predator - needs to have duplicate
#row = where p_prey = 0 for the other predator in order for proportion overlap calculation to be correct
#because it selects minimum p_prey. Also calculate new stats to compute Horisita nich overlap index too.

write.csv(p_tbl2_sex, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_Overlap_sex.csv',row.names=FALSE)

# ######### #
# By Age #
# ######### #

#Sum mni and wgtkg by predator, age & prey 
predprey_mni = fix %>% group_by(comname,age,Species) %>%
  summarise(
    mni_tot = as.numeric(round(sum(mni))),
    kgs_tot = (sum(wgtkg))
  )

#Sum mni and wgtkg total by predator & age
pred_mni = predprey_mni %>% group_by(comname,age) %>%
  summarise(
    Tmni = as.numeric(round(sum(mni_tot))),
    Tkgs = (sum(kgs_tot))
  )

#Calculate proportion prey based on mni & kgs - by predator & age
#Output to be used in calculating Proportion of dietary overlap

p_tbl2_age = full_join(predprey_mni,pred_mni,by=c('comname','age')) %>%
  ungroup() %>%
  mutate(
    p_prey = (mni_tot / Tmni),
    p_kgs = (kgs_tot / Tkgs)
  )

#Check totals
aggregate(p_tbl2_age$p_prey, list(p_tbl2_age$comname,p_tbl2_age$age), FUN=sum)

#Output p_tbl2 to excel. Fill in rows where prey consumed by only on predator - needs to have duplicate
#row = where p_prey = 0 for the other predator in order for proportion overlap calculation to be correct
#because it selects minimum p_prey. Also calculate new stats to compute Horisita nich overlap index too.

write.csv(p_tbl2_age, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_Overlap_age.csv',row.names=FALSE)

#Vegan package - species accumulation curve to evalute stomach sample size vs species richness

data(BCI)
sp1 <- specaccum(BCI)
sp2 <- specaccum(BCI, "random")
sp2
#EOF#
