#Testing BiodiversityR packages - mainly to create diet dataframe using 'makecommunitydataset' function so
#I can create species richness as a function of stomach sample size to evaluate effective samples size
#for the hard parts manuscript

#library(tidyr); library(boot); library(mgcv); library(lme4); library(AER); 
library(ggplot2)
library(tweenr)
library(ggforce)
library(concaveman)
library(ggrepel)
library(ggsci)
library(dplyr)
library(pvclust)

library(RcmdrMisc)
library(Rcmdr)
library(BiodiversityR) # also loads vegan

#Statistical Analysis of Hard Parts data for Lyssikatos & Wenzel 2022
#Import data set 'allmeta_prey_v5.csv' from ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1
#It was produced in SAS ~/seasamp/biosamp/PvHg_summary_v2.sas

####################
## Load libraries ##
####################

library(dplyr); library(tidyr); library(boot); library(mgcv); library(lme4); library(AER); library(ggplot2); library(gridExtra)
# Set the colours for the graphs
barfill <- "#4271AE"
  barlines <- "#1F3552"
    line1 <- "black"
      line2 <- "#FF3721"
#rm(list=ls(all=TRUE))

## Set Working Directory ##
setwd('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')
#setwd('D://Dell_Precision_BackUp_21Jan23/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')


######################
## Read in datasets ##
######################

#version 5#
#The format is detail prey species, so all meta data is repeated for each Tagnum
#Includes both Pv and Hg stomach samples

obs = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/allmeta_prey_v5.csv',header=TRUE)
#obs = read.csv('D://Dell_Precision_BackUp_21Jan23/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/allmeta_prey_v5.csv',header=TRUE)


##################################################
## Aggregate data ##
##################################################

#First eliminate records where guild = junk (i.e. Menidia menidia), empty, and Elasmob
#because they don't contribute to mni or kgs consumed

fix = obs %>% filter (guild != "Junk" & guild !="Elasmob" & guild !="Empty" & guild !="Benth/Piscv")
fix$guild <- droplevels(fix$guild)
dim(obs)
dim(fix)
table(obs$guild)
table(fix$guild)
table(fix$mni)

table(fix$guild,fix$comname)

df=as.data.frame(fix) #detail prey species records by stomach samples

#Transpose fix dset to make put individual prey species into columns

test.Hg<-makecommunitydataset(df, row='Tagnum1', column='Species', value='mni', 
                              factor="comname", level="Gray Seal", drop=T)
test.Pv<-makecommunitydataset(df, row='Tagnum1', column='Species', value='mni', 
                              factor="comname", level="Harbor Seal", drop=T)

library(vegan)

#Gray Seal Species Accumulation Curve
sp1.hg<-specaccum(test.Hg)
sp2.hg<-specaccum(test.Hg,"random")
summary(sp2.hg)

plot(sp1.hg, ci.type="poly", col="blue", lwd=2, ci.lty=0, ci.col="lightblue",
     main="Gray Seal (2004-2018)",ylab="No. Species (Richness)",xlab="No. Stomach Samples")

boxplot(sp2.hg, col="yellow", add=TRUE, pch="+", main="Gray Seal (2004-2018)",
        ylab="No. Species (Richness)",xlab="No. Stomach Samples")

#Harbor Seal Species Accumulation Curve
sp1.pv<-specaccum(test.Pv)
sp2.pv<-specaccum(test.Pv,"random")
summary(sp2.pv)

plot(sp1.pv, ci.type="poly", col="blue", lwd=2, ci.lty=0, ci.col="lightblue",
     main="Harbor Seal (2004-2018)",ylab="No. Species (Richness)",xlab="No. Stomach Samples")
boxplot(sp2.pv, col="yellow", add=TRUE,pch="+", main="Harbor Seal (2004-2018)",
        ylab="No. Species (Richness)",xlab="No. Stomach Samples")

################################################################################
## Notes taken from: https://t-redactyl.io/blog/2015/10/two-group-hypothesis-testing-permutation-tests.html

## Permutation Test - testing the difference in mean meal size consumed  
## between harbor and gray seals
## MNI and kgs consumed are not normally distributed so can't use a T-test
## Prey size distributions are not normally distributed either
##Mean Prey size (length & weight) is evaluated in 'preylengthdata.R'

# Test Statistic = the difference in the mean meal size 

# What permutation tests suggest as their null hypothesis is that randomly reassigning 
# (or permuting) these group (i.e. predator) labels and then taking the mean difference 
# between these new groups will give a mean difference similar to the one we got from 
# the original groups.

# The null hypothesis is that the group labels are arbitrary, and that we could get a mean difference of that size or bigger by chance alone.
# The alternative hypothesis is that the group labels are not arbitrary, and a mean difference of that size didn’t occur by chance. 
# In permutation tests, we therefore permute the group labels a large number of times, 
# and see where our original mean difference ranks among the permuted mean differences.

#First - sum mni and wgtkg by stomach sample retaining meta-data

df=as.data.frame(fix) #detail prey species records by stomach samples

table(df$age)

tagnum_mni_kgs = df %>% group_by(year,comname,Tagnum1,age,sex,Epu,season) %>%
  summarise(
    N_species = n(),
    t_mni = (sum(mni)),
    t_kgs = (sum(wgtkg))
    #sd_mni = ((mni)),
    #sd_kgs = (sd(wgtkg))
  )

#Filter out adult and juvenile samples then sum mni and wgtkg by stomach sample retaining meta-data
tagnum_mni_kgs.trim = df %>% filter(age!="adu" & age!="juv") %>%
  group_by(year,comname,Tagnum1,age,sex,Epu,season) %>%
  summarise(
    N_species = n(),
    t_mni = (sum(mni)),
    t_kgs = (sum(wgtkg))
    #sd_mni = ((mni)),
    #sd_kgs = (sd(wgtkg))
  )

## Plot histogram of t_mni consumed

# Plotting histogram of Harbor Seal t_mni consumed per stomach (i.e.per meal)
#data<-tagnum_mni_kgs
data<-tagnum_mni_kgs.trim
Pv_g1 <- ggplot(data=as.data.frame(data$t_mni[data$comname == "Harbor Seal"]), 
             aes(data$t_mni[data$comname == "Harbor Seal"])) + 
  geom_histogram(binwidth = 3, fill = barfill, colour = barlines) +
  xlab("MNI prey consumed per meal") + xlim(0,125) + ylim(0,30) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Harbor Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) 
Pv_g1

# Plotting histogram of Gray Seal t_mni consumed per stomach (i.e. per meal)
Hg_g1 <- ggplot(data=as.data.frame(data$t_mni[data$comname == "Gray Seal"]), 
             aes(data$t_mni[data$comname == "Gray Seal"])) + 
  geom_histogram(binwidth = 3, fill = barfill, colour = barlines) +
  xlab("MNI prey consumed per meal") + xlim(0,125) + ylim(0,30) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Gray Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold"))
Hg_g1

# Printing histograms
grid.arrange(Pv_g1, Hg_g1, nrow = 1, ncol = 2)

##
Pv_mean_meal_mni<- mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Harbor Seal"])
Hg_mean_meal_mni<-mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Gray Seal"])

Pv_mean_meal_kgs<- mean(tagnum_mni_kgs.trim$t_kgs[tagnum_mni_kgs.trim$comname == "Harbor Seal"])
Hg_mean_meal_kgs<-mean(tagnum_mni_kgs.trim$t_kgs[tagnum_mni_kgs.trim$comname == "Gray Seal"])


## Compute test statistics

diff.means <- mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Harbor Seal"]) -
  mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Gray Seal"])

diff.median <- median(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Harbor Seal"]) -
  median(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$comname == "Gray Seal"])

#The test statistic is 5.889 (7.25 if adults&juveniles removed), which indicates that harbor seals consumed on average ~7 more individuals
#prey when compared to gray seals, over the time period 2004-2018.

# Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = comname
#variable = t_mni or some other quantity

one.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "Harbor Seal"]) - 
    mean(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(567)

tagnum_mni_kgs.trim$resampled.group <- sample(tagnum_mni_kgs.trim$comname)

rs.mean <- mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$resampled.group == "Harbor Seal"]) - 
  mean(tagnum_mni_kgs.trim$t_mni[tagnum_mni_kgs.trim$resampled.group == "Gray Seal"])

head(tagnum_mni_kgs.trim[ , c("comname", "resampled.group", "t_mni")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, one.test(tagnum_mni_kgs.trim$comname, tagnum_mni_kgs.trim$t_mni))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means > diff.means)
sig_left <-sum(perm.means < -diff.means)
head(sig)
head(sig_left)

pvalue<-sig/1000 #one-sided (directional difference (i.e. Pv consuming MORE MNI than Hg)
                 #pvalue=0.00399 (0.0009 if trimmed). As this is less than 0.05, this means that Harbor seals consume significantly 
                 # individual prey than gray seals per meal.
twosided_pvalue<-(sig_left+sig)/1000 #two sided (non-direction null hypothesis that Pv mean mni not equal to Hg mean mni consumted)

  
mean <- data.frame(Means="Test statistic", vals = diff.means)


Pv_Hg_g2 <- ggplot(data=as.data.frame(perm.means), aes(perm.means)) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Difference in Means") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Permuted Means") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
Pv_Hg_g2

# Printing histograms
grid.arrange(Pv_g1, Hg_g1, Pv_Hg_g2, nrow = 1, ncol = 3) #arranages 3 plots on one page

hist(perm.means,labels=T) #simple histogram plot of permuted mean differences
abline(v=c(-diff.means,diff.means),lwd=2,col="red") #Adds vertical lines for two sided observed test statistic

###############################
## Use median as test statistic
## Didn't bother with this for the trimmed d-set
###############################

two.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  median(variable[resampled.group == "Harbor Seal"]) - 
    median(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(333)

tagnum_mni_kgs$resampled.group <- sample(tagnum_mni_kgs$comname)

rs.median <- median(tagnum_mni_kgs$t_mni[tagnum_mni_kgs$resampled.group == "Harbor Seal"]) - 
  median(tagnum_mni_kgs$t_mni[tagnum_mni_kgs$resampled.group == "Gray Seal"])

head(tagnum_mni_kgs[ , c("comname", "resampled.group", "t_mni")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.median <- replicate(1000, two.test(tagnum_mni_kgs$comname, tagnum_mni_kgs$t_mni))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted medians:

sig2 <- sum(perm.median > diff.median)
head(sig2)
pvalue2<-sig2/1001 #pvalue=0.00399. As this is less than 0.05, this means that Harbor seals consume significantly 
# individual prey than gray seals per meal.

median <- data.frame(Median="Test statistic", vals = diff.median)

g2 <- ggplot(data=as.data.frame(perm.median), aes(perm.median)) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Permuted Medians") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Distribution of Permuted Medians") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=median, aes(xintercept=vals, linetype = Median, 
                            colour = Median), linewidth = 1, show.legend = TRUE) + 
  scale_color_manual(values=c("Test statistic" = line2))
g2

# This is a brief introduction to permutation tests, which is a family that includes 
# well-known non-parametric methods such as the Fisher’s exact and Wilcoxon rank-sum tests.
# These tests are a useful part of your statistical arsenal when your data don’t fit the 
# assumptions of parametric tests (as is often the case). However, these of course aren’t 
# a magical fix-all to your problems and must be used sensibly! As an example, a problem 
# we might have could be that taking the mean of such skewed data is not particularly 
# meaningful, therefore doing a test of mean differences does not make sense.

# Run Permutation difference of means/median test on biomass consumed per meal instead of MNI
# Not expecting significant result because even though Pv consume significantly more individual prey
# they are of smaller size so overall mean meal biomass consumed is expected to be 
# approximately equal to the average harbor seal meal size


## Plot histogram of t_kgs consumed

# Plotting histogram of Harbor Seal t_kgs consumed per stomach (i.e.per meal)
#data<-tagnum_mni_kgs
data<-tagnum_mni_kgs.trim #has adults & juveniles removed

Pv_g1 <- ggplot(data=as.data.frame(data$t_kgs[data$comname == "Harbor Seal"]), 
                aes(data$t_kgs[data$comname == "Harbor Seal"])) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Total biomass consumed per meal (kgs)") + xlim(0,15) + ylim(0,50) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Harbor Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) 
Pv_g1

# Plotting histogram of Gray Seal t_kgs consumed per stomach (i.e. per meal)
Hg_g1 <- ggplot(data=as.data.frame(data$t_kgs[data$comname == "Gray Seal"]), 
                aes(data$t_kgs[data$comname == "Gray Seal"])) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Total biomass consumed per meal (kgs)") + xlim(0,15) + ylim(0,50) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Gray Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold"))
Hg_g1

# Printing histograms
grid.arrange(Pv_g1, Hg_g1, nrow = 1, ncol = 2)

##
Pv_mean_meal_kgs<- mean(data$t_kgs[data$comname == "Harbor Seal"])
Hg_mean_meal_kgs<-mean(data$t_kgs[data$comname == "Gray Seal"])

Pv_median_meal_kgs<- median(data$t_kgs[data$comname == "Harbor Seal"])
Hg_median_meal_kgs<-median(data$t_kgs[data$comname == "Gray Seal"])

## Compute test statistics

diff.means <- mean(data$t_kgs[data$comname == "Harbor Seal"]) -
  mean(data$t_kgs[data$comname == "Gray Seal"])

diff.median <- median(data$t_kgs[data$comname == "Harbor Seal"]) -
  median(data$t_kgs[data$comname == "Gray Seal"])

#The test statistic is -0.021kg (0.248 w/adults & juvs removed (Pv > Hg now)
#median diff=0.204kg, (0.311kg w/adults & juvs removed), which indicates that harbor and gray seals 
#on average have similar meal sizes over the time period 2004-2018.
#Pv mean = 1.82kg (1.827 same); Hg mean = 1.84kg (1.578 trimmed). Pv median = 1.19kg; Hg median = 0.98kg

# Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = comname
#variable = t_kgs or some other quantity

one.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "Harbor Seal"]) - 
    mean(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(567)

data$resampled.group <- sample(data$comname)

rs.mean <- mean(data$t_kgs[data$resampled.group == "Harbor Seal"]) - 
  mean(data$t_kgs[data$resampled.group == "Gray Seal"])

head(data[ , c("comname", "resampled.group", "t_kgs")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, one.test(data$comname, data$t_kgs))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means > diff.means)
head(sig)
pvalue<-sig/1001 #pvalue=0.525 (0.148 w/adult&juvs removed). As this is > 0.05, this means that this similar meal size observed
#for both harbor and gray seals was not due to chance. There average meal sizes
#based on stomach contents are the same.

mean <- data.frame(Means="Test statistic", vals = diff.means)

Pv_Hg_g3 <- ggplot(data=as.data.frame(perm.means), aes(perm.means)) + 
  geom_histogram(binwidth = 0.05, fill = barfill, colour = barlines) +
  xlab("Difference in Means") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Permuted Means") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))

Pv_Hg_g3

# Printing histograms
grid.arrange(Pv_g1, Hg_g1, Pv_Hg_g3, nrow = 1, ncol = 3)

###############################
## Use median as test statistic
###############################

two.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  median(variable[resampled.group == "Harbor Seal"]) - 
    median(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(333)

data$resampled.group <- sample(data$comname)

rs.median <- median(data$t_kgs[data$resampled.group == "Harbor Seal"]) - 
  median(data$t_kgs[data$resampled.group == "Gray Seal"])

head(data[ , c("comname", "resampled.group", "t_kgs")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.median <- replicate(1000, two.test(data$comname, data$t_kgs))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted medians:

sig2 <- sum(perm.median > diff.median)
head(sig2)
pvalue2<-sig2/1001 #pvalue=0.147 (w/o adults&juveniles). As this is greater than 0.05, this means that Harbor seals consume the 
# same biomass on average as gray seals per meal.

median <- data.frame(Median="Test statistic", vals = diff.median)

g2 <- ggplot(data=as.data.frame(perm.median), aes(perm.median)) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Permuted Medians") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Distribution of Permuted Medians") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=median, aes(xintercept=vals, linetype = Median, 
                              colour = Median), linewidth = 1, show.legend = TRUE) + 
  scale_color_manual(values=c("Test statistic" = line2))
g2


#Box Plots
#df<-tagnum_mni_kgs
df<-tagnum_mni_kgs.trim
table(df$comname)

#Total MNI per stomach (i.e. meal) boxplots by seal species
ggplot(data=df, aes(x=comname, y=t_mni, fill=comname)) +
  geom_boxplot(stat="boxplot", notch=FALSE, show.legend=FALSE) +
  #aes(colour=comname),
  #facet_grid(cols=vars(age), scale="free") +
  #scale_fill_viridis(discrete = TRUE, alpha=0.6) +
  scale_fill_brewer() +
  #geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
  labs(y="t_mni") +
  theme(legend.position="top", axis.text = element_text(size=10), axis.title.x = element_blank()) 
#+ geom_hline(aes(yintercept=h_line))

#Total Kgs per stomach (i.e. meal) boxplots by seal species
ggplot(data=df[df$age!="unk"&df$sex!=".",], aes(x=comname, y=t_mni, fill=comname)) +
  geom_boxplot(stat="boxplot", notch=FALSE, show.legend=FALSE) +
  facet_grid(rows=vars(sex),cols=vars(age), scale="free") +
  #scale_fill_viridis(discrete = TRUE, alpha=0.6) +
  scale_fill_brewer() +
  #geom_jitter(color="black", size=0.4, alpha=0.9, show.legend = FALSE) +
  labs(y="t_mni") +
  theme(legend.position="top", axis.text = element_text(size=8), axis.title.x = element_blank()) 
#+ geom_hline(aes(yintercept=h_line))
