#Statistical Analysis of Hard Parts data for Lyssikatos & Wenzel 2024
#Import data set 'allmeta_prey_v5.csv' from ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1
#It was produced in SAS ~/seasamp/biosamp/PvHg_summary_v2.sas

####################
## Load libraries ##
####################

library(dplyr); library(tidyr); library(boot); library(mgcv); library(lme4); library(AER); library(ggplot2); library(gridExtra)
# Set the colours for the graphs
barfill <- "#4271AE"
barlines <- "#1F3552"
line1 <- "black"
line2 <- "#FF3721"

#rm(list=ls(all=TRUE))

## Set Working Directory ##
setwd('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')
#setwd('D://Dell_Precision_BackUp_21Jan23/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')


######################
## Read in datasets ##
######################

#Includes both Pv and Hg stomach samples
#The following data was output from HgPv_preylengths.sas -> each record is an individual animal consumed
#along with all the relevant meta-data that is repeated for individual animal length and weight

obsprey = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_preylengths.csv',header=TRUE)

#Filter out empty stomachs - this removes stranded carcasses too and guild = empty
table(obsprey$comname,obsprey$guild)
obsprey<-(obsprey[obsprey$guild!="Empty",])
table(obsprey$Species)
look<-(obsprey[obsprey$guild=="Junk",]) #This is menidia menidia

#Boxplot of Sandlance lengths consumed by seals

plot.new()
par(mai=c(1.25,1.0,0.75,0.5))
par(mfrow=c(1,1))
#US 
g <- boxplot(FL_cm ~ comname, data=(obsprey[obsprey$Species=="Ammodytes",]), plot=0)

boxplot(FL_cm ~ comname, data=(obsprey[obsprey$Species=="Ammodytes",]), main="SandLance Prey", ylab="CM",ylim=c(0,30))

text(1:length(g$n), g$stats[5,]+2, paste("", g$n), col=4) #Puts sample size at top of whisker

#Subset sand lance only
obs_Ammo<-(obsprey[obsprey$Species=="Ammodytes",])
obs_Ammo_Hg<-(obs_Ammo[obs_Ammo$comname=="Gray Seal",])

#Tabulate freq of Ammo by area, season
table(obs_Ammo$age,distinct=obs_Ammo$comname)
table(obs_Ammo$Tagnum1,distinct=obs_Ammo$comname)
table(obs_Ammo_Hg$Tagnum1,distinct=obs_Ammo_Hg$age)

#Boxplot of Cod lengths consumed by seals

plot.new()
par(mai=c(1.25,1.0,0.75,0.5))
par(mfrow=c(1,1))
#US 
g <- boxplot(FL_cm ~ comname, data=(obsprey[obsprey$Species=="Gadus morhua",]), plot=0)

boxplot(FL_cm ~ comname, data=(obsprey[obsprey$Species=="Gadus morhua",]), main="Cod Prey", ylab="CM",ylim=c(0,60))

text(1:length(g$n), g$stats[5,]+2, paste("", g$n), col=4) #Puts sample size at top of whisker

table(obsprey$negear,distinct=obsprey$comname)
research<-(obsprey[obsprey$negear=="Res",])

#Also remove bottom trawl and mwt gear types
obsprey<-(obsprey[obsprey$negear==100 | obsprey$negear==117 | obsprey$negear=="Res",])
hist(obsprey$FL_cm)

#Look at prey that are <= 12cm and <=9cm
secondary_12cm<-(obsprey[obsprey$FL_cm<=12,])
secondary_9cm<-(obsprey[obsprey$FL_cm<=9,])
table(secondary_12cm$Species)
table(secondary_9cm$Species)

hist(secondary_12cm$FL_cm)
hist(secondary_9cm$FL_cm)

table(obsprey$Species)

select_second_pg1 <- subset(obsprey, Species=="Sebastes marinus" | Species=="Citharichthys arctifrons" | Species=="Gadus morhua")

select_second_pg2 <- subset(obsprey, Species=="Merluccius bilinearis_sm" | Species=="Merluccius bilinearis_lg" |
                          Species=="Urophycis chuss_smd" | Species=="Urophycis chuss_lg")

ggplot(select_second_pg1, aes(x = FL_cm)) +
  geom_histogram(fill = "white", colour = "black") +
  facet_grid(Species ~ .)

ggplot(select_second_pg2, aes(x = FL_cm)) +
  geom_histogram(fill = "white", colour = "black") +
  facet_grid(Species ~ .)
##
#End exploring length distributions for select species
##

#Back to preparing data for merging obs lengths with commercial lengths

obsprey$type<-c("seals") #Create new column for merging with commercial catch data
obsprey$NUMLEN<-as.numeric(c(1))
obsprey$t_len<-obsprey$FL_cm*obsprey$NUMLEN

seal.cod<-(obsprey[obsprey$Species=="Gadus morhua",])
hist(seal.cod$FL_cm)
xobs_len=sum(seal.cod$t_len)/sum(seal.cod$NUMLEN)

write.csv(seal.cod, "C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1//seal_cod.csv", row.names=FALSE)

seal.rhake<-(obsprey[obsprey$Species=="Urophycis chuss_smd" | obsprey$Species=="Urophycis chuss_lg",])
hist(seal.rhake$FL_cm)
xobs_len=sum(seal.rhake$t_len)/sum(seal.rhake$NUMLEN)

seal.shake<-(obsprey[obsprey$Species=="Merluccius bilinearis_sm" | obsprey$Species=="Merluccius bilinearis_lg",])
hist(seal.shake$FL_cm)
xobs_len=sum(seal.shake$t_len)/sum(seal.shake$NUMLEN)
#obsprey = read.csv('D://Dell_Precision_BackUp_21Jan23/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_preylengths.csv',header=TRUE)

#The following csv file was produced in SAS in ~/seasamp/GN/gnlen.2004.sas
#It's length frequency data from observed gillnet trips only - both OBS & ASM 2004-2018
obscatch = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/obslen0418_v1.csv',header=TRUE)
obscatch$type<-c("fishers") #Create new column for merging with seal prey length data
obscatch$t_len<-obscatch$LENANML*obscatch$NUMLEN

comm.cod<-(obscatch[obscatch$COMNAME=="COD, ATLANTIC",])
xcom_len=sum(comm.cod$t_len)/sum(comm.cod$NUMLEN)
hist(comm.cod$LENANML)

comm.rhake<-(obscatch[obscatch$COMNAME=="HAKE, RED (LING)",])
xcom_len=sum(comm.rhake$t_len)/sum(comm.rhake$NUMLEN)
hist(comm.rhake$LENANML)

comm.shake<-(obscatch[obscatch$COMNAME=="HAKE, SILVER (WHITING)",])
xcom_len=sum(comm.shake$t_len)/sum(comm.shake$NUMLEN)
hist(comm.shake$LENANML)

#Figures 6-8 in manuscript
par(mfrow=c(2,1)) #page will have 2 row with 1 columns
par(mai=c(0.8,0.5,0.5,0.5))

hist(seal.cod$FL_cm, xlim=c(0,160), xaxp=c(0,160,8), ylim=c(0,25), xlab="Seal Prey Length (cm)",
     main="Atlantic Cod (2004-2018)", cex.lab=1.0, cex.main=1.0)
hist(comm.cod$LENANML, xlim=c(0,160), xaxp=c(0,160,8), ylim=c(0,40000), cex.lab=1.0, main=NULL, 
     xlab="Gillnet Catch Length (cm)")

hist(seal.rhake$FL_cm, xlim=c(0,100), xaxp=c(0,100,5), ylim=c(0,300), xlab="Seal Prey Length (cm)",
     main="Red Hake (2004-2018)", cex.lab=1.0, cex.main=1.0)
hist(comm.rhake$LENANML, xlim=c(0,100), xaxp=c(0,100,5), ylim=c(0,300), cex.lab=1.0, main=NULL, 
     xlab="Gillnet Catch Length (cm)")

hist(seal.shake$FL_cm, xlim=c(0,100), xaxp=c(0,100,5), ylim=c(0,800), xlab="Seal Prey Length (cm)",
     main="Silver Hake (2004-2018)", cex.lab=0.9, cex.main=1.0)
hist(comm.shake$LENANML, xlim=c(0,100), xaxp=c(0,100,5), ylim=c(0,900), cex.lab=0.9, main=NULL, 
     xlab="Gillnet Catch Length (cm)")

table(obscatch$PROGRAM,obscatch$CATDISP)
table(obscatch$NEGEAR)

#Left off here Sunday night 3/5 -  Still need to append seal and commercial catch
#data to run permutation test

names(obsprey)
summary(obsprey[obsprey$Species=="Gadus morhua", 31])
names(obscatch)
summary(obscatch[obscatch$COMNAME=="COD, ATLANTIC", 16])

#as.data.frame(table(obsprey[obsprey$tripid=="E35085",3])) #Look at prey found in stomach from a selected trips
cod.prey<-as.data.frame(obsprey[obsprey$Species=="Gadus morhua",3])
table(obsprey[obsprey$Species=="Gadus morhua" & obsprey$comname=="Gray Seal",14]) #freq of cod consumed by year by Hg
table(obsprey[obsprey$Species=="Gadus morhua" & obsprey$comname=="Harbor Seal",14]) #freq of cod consumed by year by Pv

#as.data.frame(table(obscatch[obscatch$TRIPID=="E35085",19])) #Look at catch from same obs trip
cod.catch<-as.data.frame(table(obscatch[obscatch$COMNAME=="COD, ATLANTIC",19])) #freq of cod in obs trips

#Use simple barplot function instead of ggplots below to show length frequency comparisons

#Atlantic Cod
par(mfrow=c(2,1)) #page will have 2 row with 1 columns

par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(obsprey[obsprey$Species=="Gadus morhua",31], breaks = seq(0, 150, by = 10))),
        main="Atlantic Cod (2004-2018)", legend="YoY seal stomach sample")

par(mai=c(0.85,0.5,0.25,0.5))
barplot(table(cut(obscatch[obscatch$COMNAME=="COD, ATLANTIC",16], breaks = seq(0, 150, by = 10))),
        xlab="Length (cm)", col=c("blue"), legend="Sampled catch")

HgPv_codprey_len<-mean(obsprey$FL_cm[obsprey$Species=="Gadus morhua"])
#Pv_xprey_len.trim<- mean(data$FL_cm[data$comname == "Harbor Seal" & data$FL_cm>6])

Gill_codprey_len<-mean(obscatch$LENANML[obscatch$COMNAME=="COD, ATLANTIC"])
#hg_xprey_len.trim<- mean(data$FL_cm[data$comname == "Gray Seal" & data$FL_cm>12])

#Compute test statistic for permutation test
diff.means <- mean(obsprey$FL_cm[obsprey$Species=="Gadus morhua"]) -
  mean(obscatch$LENANML[obscatch$COMNAME=="COD, ATLANTIC"])

#The test statistic is -52.69cm, which indicates that (yoy) seals consumed prey lengths 
#on average 51.07cm smaller than observed commercial gillnet catches. 
#over the time period 2004-2018.


#First, Append obsprey and obscatch into one dataframe, resampling variable = type
#Need to rename columns to match in each data set before appending
#Final data frame should have seven columns: 
#tripid, predator (gray seal, harbor seal, or humans), species  (prey), FL_cm (prey size), 
#NUMLEN (number or seal prey consumed), t_len (total number of commercial prey caught), and type (seals or fishers)

#Fishers dataframe
df1_obscatch<-obscatch %>% 
  rename(
    tripid = TRIPID,
    FL_cm = LENANML,
    Species = COMNAME,
    
  )

#Add new column to df1
predator = c("humans")
df1_obscatch$predator <- predator
names(df1_obscatch)

#select the 7 variables needed
df1_catches<-df1_obscatch %>% select(tripid, predator, type, Species, FL_cm, NUMLEN, t_len)
summary(df1_catches)

#Seals dataframe
df2_obsprey<-obsprey %>% 
  rename(
    predator=comname
    
  )
names(df2_obsprey)

#select the 7 variables needed
df2_seals<-df2_obsprey %>% select(tripid, predator, type, Species, FL_cm, NUMLEN, t_len)
summary(df2_seals)

#Append obs catches with seal prey data
df3 <- rbind(df1_catches, df2_seals)
head(df3)
table(df3$Species)
table(df3$type)

# Now can Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = type (seals, fishers)
#variable = FL_cm or some other quantity

cod.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "seals"]) - 
    mean(variable[resampled.group == "fishers"])
}

# Example of how resampling works:
set.seed(303)

# select cod only
cod<-(df3[df3$Species=="Gadus morhua" | df3$Species=="COD, ATLANTIC",])

cod$resampled.group <- sample(cod$type)
table(cod$resampled.group)

rs.mean <- mean(cod$FL_cm[cod$resampled.group == "seals"]) - 
  mean(cod$FL_cm[cod$resampled.group == "fishers"])

head(cod[ , c("type", "resampled.group", "FL_cm")])
table(cod$resampled.group)

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(2000, cod.test(cod$type, cod$FL_cm))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means > -diff.means)
sig_left <-sum(perm.means < diff.means)
head(sig)
head(sig_left)

pvalue<-sig/1000 #one-sided (directional difference (i.e. seals consuming cod as large as fishers cod catches)
#pvalue=0 (0.0009 if trimmed). As this is less than 0.05, this means that seals consume significantly smaller cod 

twosided_pvalue<-(sig_left+sig)/1000 #two sided (non-direction null hypothesis that seal mean cod size is not equal to fishers mean cod size


mean <- data.frame(Means="Test statistic", vals = diff.means)

# Printing histograms
#grid.arrange(Pv_g1, Hg_g1, Pv_Hg_g2, nrow = 1, ncol = 3) #arranages 3 plots on one page
par(mfrow=c(1,1))
hist(perm.means,labels=T) #simple histogram plot of permuted mean differences
abline(v=c(-diff.means,diff.means),lwd=2,col="red") #Adds vertical lines for two sided observed test statistic

Seals_Fishers <- ggplot(data=as.data.frame(perm.means), aes(perm.means)) + 
  geom_histogram(binwidth = 1, fill = barfill, colour = barlines) +
  xlab("Difference in Means") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Permuted Means") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
Seals_Fishers

##########################################################################

##Silver Hake
summary(obsprey[obsprey$Species=="Merluccius bilinearis_sm", 31])
summary(obsprey[obsprey$Species=="Merluccius bilinearis_lg", 31])
summary(obscatch[obscatch$COMNAME=="HAKE, SILVER (WHITING)", 16])

par(mfrow=c(3,1)) #page will have 3 row with 1 columns

par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(obsprey[obsprey$Species=="Merluccius bilinearis_sm",31], breaks = seq(0, 100, by = 10))),
        main="Silver Hake_sm (2004-2018)", legend="YoY seal stomach sample")

par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(obsprey[obsprey$Species=="Merluccius bilinearis_lg",31], breaks = seq(0, 100, by = 10))),
        main="Silver Hake_lg (2004-2018)")

par(mai=c(0.55,0.5,0.25,0.5))
barplot(table(cut(obscatch[obscatch$COMNAME=="HAKE, SILVER (WHITING)",16], breaks = seq(0, 100, by = 10))),
        xlab="Length (cm)", col=c("blue"), main="Silver Hake (2004-2018)", legend="Sampled catch")

#Compute test statistic for permutation test
diff.means <- mean(obsprey$FL_cm[obsprey$Species=="Merluccius bilinearis_sm" | obsprey$Species=="Merluccius bilinearis_lg"]) -
  mean(obscatch$LENANML[obscatch$COMNAME=="HAKE, SILVER (WHITING)"])

# Now can Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = type (seals, fishers)
#variable = FL_cm or some other quantity

shake.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "seals"]) - 
    mean(variable[resampled.group == "fishers"])
}

# Example of how resampling works:
set.seed(303)

# select silver hake only
shake<-(df3[df3$Species=="Merluccius bilinearis_sm" | df3$Species=="Merluccius bilinearis_lg" | df3$Species=="HAKE, SILVER (WHITING)",])

shake$resampled.group <- sample(shake$type)
table(shake$resampled.group)

rs.mean <- mean(shake$FL_cm[shake$resampled.group == "seals"]) - 
  mean(shake$FL_cm[shake$resampled.group == "fishers"])

head(shake[ , c("type", "resampled.group", "FL_cm")])
table(shake$resampled.group)

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, shake.test(shake$type, shake$FL_cm))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means > -diff.means)
sig_left <-sum(perm.means < diff.means)
head(sig)
head(sig_left)

pvalue<-sig/1000 #one-sided (directional difference (i.e. seals consuming silver hake as large as fishers cod catches)
#pvalue=0 (0.0009 if trimmed). As this is less than 0.05, this means that seals consume significantly smaller cod 

twosided_pvalue<-(sig_left+sig)/1000 #two sided (non-direction null hypothesis that seal mean silver hake size is not equal to fishers mean cod size


mean <- data.frame(Means="Test statistic", vals = diff.means)

# Printing histograms
#grid.arrange(Pv_g1, Hg_g1, Pv_Hg_g2, nrow = 1, ncol = 3) #arranages 3 plots on one page
par(mfrow=c(1,1))
hist(perm.means,labels=T) #simple histogram plot of permuted mean differences
abline(v=c(-diff.means,diff.means),lwd=2,col="red") #Adds vertical lines for two sided observed test statistic

##
##Red Hake
summary(obsprey[obsprey$Species=="Urophycis chuss_smd", 31])
summary(obsprey[obsprey$Species=="Urophycis chuss_lg", 31])
summary(obscatch[obscatch$COMNAME=="HAKE, RED (LING)", 16])

par(mfrow=c(3,1)) #page will have 3 row with 1 columns

par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(obsprey[obsprey$Species=="Urophycis chuss_smd",31], breaks = seq(0, 100, by = 10))),
        main="Red Hake_smd (2004-2018)", legend="YoY seal stomach sample")

par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(obsprey[obsprey$Species=="Urophycis chuss_lg",31], breaks = seq(0, 100, by = 10))),
        main="Red Hake_lg (2004-2018)", ylim=c(0,50))

par(mai=c(0.55,0.5,0.25,0.5))
barplot(table(cut(obscatch[obscatch$COMNAME=="HAKE, RED (LING)",16], breaks = seq(0, 100, by = 10))),
        xlab="Length (cm)", col=c("blue"), main="Red Hake (2004-2018)", legend="Sampled catch")


#Compute test statistic for permutation test
diff.means <- mean(obsprey$FL_cm[obsprey$Species=="Urophycis chuss_smd" | obsprey$Species=="Urophycis chuss_lg"]) -
  mean(obscatch$LENANML[obscatch$COMNAME=="HAKE, RED (LING)"])

# Now can Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = type (seals, fishers)
#variable = FL_cm or some other quantity

rhake.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "seals"]) - 
    mean(variable[resampled.group == "fishers"])
}

# Example of how resampling works:
set.seed(303)

# select red hake only
rhake<-(df3[df3$Species=="Urophycis chuss_smd" | df3$Species=="Urophycis chuss_lg" | df3$Species=="HAKE, RED (LING)",])

rhake$resampled.group <- sample(rhake$type)
table(rhake$resampled.group)

rs.mean <- mean(rhake$FL_cm[rhake$resampled.group == "seals"]) - 
  mean(rhake$FL_cm[rhake$resampled.group == "fishers"])

head(rhake[ , c("type", "resampled.group", "FL_cm")])
table(rhake$resampled.group)

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, rhake.test(rhake$type, rhake$FL_cm))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means > -diff.means)
sig_left <-sum(perm.means < diff.means)
head(sig)
head(sig_left)

pvalue<-sig/1000 #one-sided (directional difference (i.e. seals consuming silver hake as large as fishers cod catches)
#pvalue=0 (0.0009 if trimmed). As this is less than 0.05, this means that seals consume significantly smaller cod 

twosided_pvalue<-(sig_left+sig)/1000 #two sided (non-direction null hypothesis that seal mean silver hake size is not equal to fishers mean cod size


mean <- data.frame(Means="Test statistic", vals = diff.means)

# Printing histograms
#grid.arrange(Pv_g1, Hg_g1, Pv_Hg_g2, nrow = 1, ncol = 3) #arranages 3 plots on one page
par(mfrow=c(1,1))
hist(perm.means,labels=T) #simple histogram plot of permuted mean differences
abline(v=c(-diff.means,diff.means),lwd=2,col="red") #Adds vertical lines for two sided observed test statistic


## 21-Nov-2023
## END of PERMUTATION Test - testing observed difference in mean prey size between seals and fishers
## for results section manuscript - page 11


### Below are bar plots using ggplot but the above simpler version is preferred for now

#Length frequency plot of observed catch data for one selected trip
ggplot(data=obscatch[obscatch$COMNAME=="COD, ATLANTIC",], aes(x=LENANML, y=NUMLEN, fill=COMNAME)) +
  #facet_grid(rows=vars(COMNAME), scale="free") +
  #geom_point(stat="identity", position=pd) +
  #scale_fill_manual(values=c("grey", "brown")) +
  scale_fill_discrete() +
  scale_x_continuous(breaks=seq(0,180,20)) +
  geom_bar(stat="identity", position=position_dodge()) +
  #geom_errorbar(aes(ymin=x_Len-se_Len, ymax=x_Len+se_Len), width=.4, position=pd) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank()) #,
        #axis.text.x = element_text(angle=90, vjust=1, hjust=1))  
  
##############################################################################################  
#Number of stomach sample per predator
n_stomach = obsprey %>% group_by(comname) %>%
  summarize(count = n_distinct(Tagnum1))

n_trips = obsprey %>% group_by(year, comname, tripid, Tagnum1) %>%
  summarize(count = n_distinct(Species),
            totmni = n_distinct)

tag_mni = obsprey %>% group_by(year, comname, tripid, Tagnum1) %>%
  summarize(count = n_distinct(Species),
            totmni = n())

tag_lfreq = obsprey %>% group_by(year, comname, tripid, Tagnum1, Species, FL_cm) %>%
  summarize(numlen = n())

hist(as.data.frame(tag_lfreq[tag_lfreq$Species=="Gadus morhua",6]))

#Length frequency plot of stomach content data for one selected trip
ggplot(data=tag_lfreq[tag_lfreq$Species=="Gadus morhua",], aes(x=FL_cm, y=numlen, fill=comname)) +
  facet_grid(rows=vars(comname), scale="free") +
  #geom_point(stat="identity", position=pd) +
  scale_fill_manual(values=c("gray", "brown")) +
  #scale_fill_discrete() +
  #scale_x_continuous(breaks=seq(0,60,10)) +
  geom_bar(stat="identity", position=position_dodge()) +
  #ylim(0,5) +
  #xlim(0,30) +
    #geom_errorbar(aes(ymin=x_Len-se_Len, ymax=x_Len+se_Len), width=.4, position=pd) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank()) #,
        #axis.text.x = element_text(angle=90, vjust=1, hjust=1))  

#Next step is to merge stomach length frequency data with trip length frequency data - merging on
#Tripid - using stomach meta-data for time/area information.
#Note: not all kept catch are sampled! There are sampling priorities. So if the species don't match
#between the two data sets it doesn't mean the trip didn't catch the prey found in seal stomachs -
#it could mean that the particular prey wasn't sampled for length data. Would have to look at catch
#composition for the trip. The point of this comparison is to compare the size of prey consumed relative
#to fisherman's catches so may just wnat to show total length frequency distribution and ignores species
#all together. 

#LEFT OFF HERE FRIDAY NIGHT 11-11-22

#table(obs$guild)
#table(obs$Species)
#table(obs$tripid)

#Plots of mean prey length by species and other factors
df<-obsprey

fix = df %>% filter (Species != "" & Species !="Cynoscion regalis" & Species !="Conger oceanicus" &
                       Species !="Unidentified flatfish" & Species != "Unidentified eel" & 
                       Species !="Menidia menidia" & Species != "Unknown gadidae" & Species != "Urophycis spp." &
                       FL_cm != -0.546074)

fix2 = df %>% filter (Species != "" & FL_cm != -0.546074)

fix$Species <- droplevels(fix$Species)
table(fix$Species)

#Calculate description stats: standard deviation, standard error of the mean, and a (default 95%) confidence interval
df1 = fix %>% group_by(comname,Species) %>%
  summarise(
    N_stomachs = (n_distinct(Tagnum1)),
    x_Len = mean(FL_cm, na.rm = TRUE),
    x_kgs = mean(FW_kg, na.rm = TRUE),
    sd_Len = sd(FL_cm, na.rm = TRUE),
    sd_Kgs = sd(FW_kg, na.rm = TRUE),
    n_species=n()) %>%
  mutate(se_Len = sd_Len/sqrt(n_species),
         se_Kgs = sd_Kgs/sqrt(n_species),
         lower.ci.FL = x_Len - qt(1 - (0.05 / 2), n_species - 1) * se_Len,
         upper.ci.FL = x_Len + qt(1 - (0.05 / 2), n_species - 1) * se_Len)
        #Try log-normal CI to address skewness in data (long right hand tails)


# Test if length frequency data are normally distributed
ks.test((fix2[fix2$comname=="Harbor Seal",31]), "pnorm")
ks.test((fix2[fix2$comname=="Gray Seal",31]), "pnorm")


#fish length (FL_cm)
summary(fix2[fix2$comname=="Harbor Seal",31:32])
summary(fix2[fix2$comname=="Gray Seal",31:32])

par(mfrow=c(2,2)) #page will have 2 row with 2 columns

par(mai=c(0.45,0.5,0.5,0.5))
hist(fix2[fix2$comname=="Harbor Seal",31], xlim=c(0,75),
     main="Harbor Seal: prey length (cm)")
hist(fix2[fix2$comname=="Gray Seal",31], xlim=c(0,75),
     main="Gray Seal: prey length (cm)")

#fish weight (FW_kg)
par(mai=c(0.45,0.5,0.5,0.5))
hist(fix2[fix2$comname=="Harbor Seal",32],breaks=50, xlim=c(0,3.5), 
     main="Harbor Seal: prey weight (kg)")

hist(fix2[fix2$comname=="Gray Seal",32], breaks=50, xlim=c(0,3.5), ylim=c(0,1000),
     main="Gray Seal: prey weight (kg)")

#Test if two distributions come from the same population
#Two-sample Kolmogorov-Smirnov test - assumes normality
ks.test((fix2[fix2$comname=="Harbor Seal",31]), (fix2[fix2$comname=="Gray Seal",31]))

#data:  (fix[fix$comname == "Harbor Seal", 31]) and (fix[fix$comname == "Gray Seal", 31])
#D = 0.30813, p-value < 2.2e-16
#alternative hypothesis: two-sided
#We have sufficient evidence to say that the two sample datasets do not come from the 
#same distribution.

#Test if two distributions come from the same population
#Non-parametric Wilcoxon test

testln <- wilcox.test(FL_cm ~ comname, data = fix2,
                    exact = FALSE)
testln

#Test biomass consumed
testwt <- wilcox.test(FW_kg ~ comname, data = fix2,
                    exact = FALSE)
testwt

#Look at species where length is < 15cm for gray seals
names(fix2)

peak0to5 = fix2  %>% filter (FL_cm >= 0 & FL_cm <= 5) %>%
  group_by(comname, Species) %>%
  summarize(Freq=n())

peek = fix2  %>% filter (FL_cm >= 15 & FL_cm <= 20) %>%
  group_by(comname, Species) %>%
  summarize(Freq=n())

peek2 = fix2  %>% filter (FL_cm >= 25 & FL_cm <= 30) %>%
  group_by(comname, Species) %>%
  summarize(Freq=n())

#ggplot(data=fix[fix$age=='yoy',], aes(x=FL_cm, fill=comname)) +
ggplot(data=fix2, aes(x=FL_cm, fill=comname)) +
  geom_density(alpha=0.5) +
  xlim(0,75) +
  #geom_histogram(binwidth=2.0, alpha=0.5, position="identity") +
  theme_minimal()

ggplot(data=fix2, aes(x=FW_kg, fill=comname)) +
  geom_density(alpha=0.5) +
  xlim(0,75) +
  #geom_histogram(binwidth=2.0, alpha=0.5, position="identity") +
  theme_minimal()

#Here 6 Jan
summary(fix2[fix2$comname=="Harbor Seal",31:32])
summary(fix2[fix2$comname=="Gray Seal",31:32])


#Calculate description stats: standard deviation, standard error of the mean, and a (default 95%) confidence interval
#By predator for Table 2
df2 = fix %>% group_by(comname) %>%
  summarise(
    N_stomachs = (n_distinct(Tagnum1)),
    x_Len = mean(FL_cm, na.rm = TRUE),
    x_kgs = mean(FW_kg, na.rm = TRUE),
    sd_Len = sd(FL_cm, na.rm = TRUE),
    sd_Kgs = sd(FW_kg, na.rm = TRUE),
    n_prey=n()) %>%
  mutate(se_Len = sd_Len/sqrt(n_prey),
         se_Kgs = sd_Kgs/sqrt(n_prey),
         lower.ci.FL = x_Len - qt(1 - (0.05 / 2), n_prey - 1) * se_Len,
         upper.ci.FL = x_Len + qt(1 - (0.05 / 2), n_prey - 1) * se_Len,
         lower.ci.FW = x_kgs - qt(1 - (0.05 / 2), n_prey - 1) * se_Kgs,
         upper.ci.FW = x_kgs + qt(1 - (0.05 / 2), n_prey - 1) * se_Kgs)
          #Try log-normal CI to address skewness in data (long right hand tails)

# Plot mean length and with standard error of the mean
pd <- position_dodge(0.9) # move to the left and right

ggplot(data=df1[df1$x_Len!="",], aes(y=x_Len, x=Species, fill=comname)) +
  #facet_grid(rows=vars(sex), scale="free") +
  #geom_point(stat="identity", position=pd) +
  scale_fill_manual(values=c("grey", "brown")) +
  geom_bar(stat="identity", position=position_dodge()) +
  geom_errorbar(aes(ymin=x_Len-se_Len, ymax=x_Len+se_Len), width=.4, position=pd) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank(),
      axis.text.x = element_text(angle=90, vjust=1, hjust=1))

  #geom_errorbar(aes(xmin=x_mni-sd_mni, xmax=x_mni+sd_mni), width=.2,
                #position=position_dodge(.9))

#How does it look when using empirical 95% CI insted of std error CIs
#Due to small sample size in data there are some negative lower CI's 
  # such as: cunner (pv), fourspot (pv), plaice (pv), herring (hg), blueback (hg)

ggplot(data=df1[df1$x_Len!="",], aes(y=x_Len, x=Species, fill=comname)) +
  #facet_grid(rows=vars(sex), scale="free") +
  #geom_point(stat="identity", position=pd) +
  scale_fill_manual(values=c("grey", "brown")) +
  geom_bar(stat="identity", position=position_dodge()) +
  geom_errorbar(aes(ymin=lower.ci.FL, ymax=upper.ci.FL), width=.4, position=pd) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text.x = element_text(angle=90, vjust=1, hjust=1))

#Try using log-normal CIs - not done yet

table(fix$Epu)

#Also try boxplots again
ggplot(data=fix, aes(y=FL_cm, x=Species, fill=comname)) +
  facet_grid(rows=vars(sex), scale="free") +
  scale_fill_manual(values=c("grey", "brown")) +
  #scale_fill_brewer(palette="Dark2") +
  geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=comname), outlier.color="red", outlier.shape=1,  show.legend=FALSE) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text.x = element_text(angle=90, vjust=1, hjust=1))

#Size of fish patterns are much clearer when panels are by predator
ggplot(data=fix, aes(y=FL_cm, x=Species, fill=Epu)) +
  facet_grid(rows=vars(comname)) +
  scale_fill_manual(values=c("red","green", "blue", "cyan")) +
  #scale_fill_brewer(palette="Dark2") +
  geom_boxplot(stat="boxplot", notch=FALSE, aes(fill=Epu), outlier.color="red", outlier.shape=1, show.legend=TRUE) +
  theme(axis.text = element_text(size=8), axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text.x = element_text(angle=90, vjust=1, hjust=1))

dim(fix)
par(mai=c(0.45,0.5,0.5,0.5))
barplot(table(cut(fix[fix$Species=="Gadus morhua",31], breaks = seq(0, 100, by = 10))),
        main="Cod (2004-2018)", ylim=c(0,50))



## Add sample size to bars ## - not done yet
## Or filter out prey where n < 3

## Overall pattern is that gray seals consume larger fish than harbor seals - makes sense

## Statistical test comparing mean length consumed by each predator for each prey
 ## e.g. 2x1 table comparing mean length of haddock consumbed by Pv vs Hg
#Two sample t-test for normal data
#Mann Whitney U test (non-parametric) for non-normal data

#Permutation test of 2 group means or medians (whatever your statistic of choice is)


## PERMUTATION HYPOTHESIS TESTING ##
#Run permutation testing difference in mean prey size and biomass
#Use object=fix and statistic = FL_cm and FW_kg
#Copy permutation code from SpecAccu_curve.R script

## 11 Feb-2023 - take out fish lengths <12cm to address secondary consumption 
## will shift mean size of prey for both predators
##
#Look at redfish
table(fix$Species)

hist(fix$FL_cm[fix$Species=="Sebastes marinus"])

data<-(fix)
pvdata.trim<-fix[fix$comname == "Harbor Seal" & fix$FL_cm>6,]
hgdata.trim<-fix[fix$comname == "Gray Seal" & fix$FL_cm>12,]

Pv_xprey_len<-mean(data$FL_cm[data$comname == "Harbor Seal"])

Pv_xprey_len.trim<- mean(data$FL_cm[data$comname == "Harbor Seal" & data$FL_cm>6])

Hg_xprey_len<-mean(data$FL_cm[data$comname == "Gray Seal"])

hg_xprey_len.trim<- mean(data$FL_cm[data$comname == "Gray Seal" & data$FL_cm>12])

#Pv_mdprey_len<- median(data$FL_cm[data$comname == "Harbor Seal"])
#Hg_mdprey_len<-median(data$FL_cm[data$comname == "Gray Seal"])

#mean <- data.frame(Means="Test statistic", vals = Pv_xprey_len)
mean <- data.frame(Means="Test statistic", vals = Pv_xprey_len.trim)

# First - plot histogram of Harbor Seal prey FL_cm consumed overall Pv samples

Pv_preylen <- ggplot(data=as.data.frame(pvdata.trim$FL_cm[pvdata.trim$comname == "Harbor Seal"]), 
                aes(pvdata.trim$FL_cm[pvdata.trim$comname == "Harbor Seal"])) + 
  geom_histogram(binwidth = 2, fill = barfill, colour = barlines) +
  xlab("Prey sizes (cm) consumed") + ylim(0,200) + xlim(0,80) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Harbor Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                          colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
Pv_preylen

# Plot histogram of Gray Seal prey FL_cm consumed overall Hg samples
#mean <- data.frame(Means="Test statistic", vals = Hg_xprey_len)
mean <- data.frame(Means="Test statistic", vals = hg_xprey_len.trim)

Hg_preylen <- ggplot(data=as.data.frame(hgdata.trim$FL_cm[hgdata.trim$comname == "Gray Seal"]), 
                aes(hgdata.trim$FL_cm[hgdata.trim$comname == "Gray Seal"])) + 
  geom_histogram(binwidth = 2, fill = barfill, colour = barlines) +
  xlab("Prey sizes (cm) consumed") + ylim(0,200) + xlim(0,80) +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Gray Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                          colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
Hg_preylen

# Printing histograms
grid.arrange(Pv_preylen, Hg_preylen, nrow = 1, ncol = 2)


#Pv_mean_meal_kgs<- mean(tagnum_mni_kgs$t_kgs[tagnum_mni_kgs$comname == "Harbor Seal"])
#Hg_mean_meal_kgs<-mean(tagnum_mni_kgs$t_kgs[tagnum_mni_kgs$comname == "Gray Seal"])


## Compute test statistics

#diff.means <- mean(data$FL_cm[data$comname == "Harbor Seal"]) -
  #mean(data$FL_cm[data$comname == "Gray Seal"])

#diff.median <- median(data$FL_cm[data$comname == "Harbor Seal"]) -
  #median(data$FL_cm[data$comname == "Gray Seal"])

diff.means <- mean(pvdata.trim$FL_cm[pvdata.trim$comname == "Harbor Seal"]) -
  mean(hgdata.trim$FL_cm[hgdata.trim$comname == "Gray Seal"])

diff.median <- median(pvdata.trim$FL_cm[pvdata.trim$comname == "Harbor Seal"]) -
  median(hgdata.trim$FL_cm[hgdata.trim$comname == "Gray Seal"])

#The test statistic is -5.51 (-7.96 if trimmed), which indicates that harbor seals consumed prey lengths 
#on average 5.5cm smaller that gray seals 
#over the time period 2004-2018.

# Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = comname
#variable = FL_cm or some other quantity

one.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "Harbor Seal"]) - 
    mean(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(333)

data.trim<-rbind(pvdata.trim,hgdata.trim) #this df has secondary prey removed

data.trim$resampled.group <- sample(data.trim$comname)

rs.mean <- mean(data.trim$FL_cm[data.trim$resampled.group == "Harbor Seal"]) - 
  mean(data.trim$FL_cm[data.trim$resampled.group == "Gray Seal"])

head(data.trim[ , c("comname", "resampled.group", "FL_cm")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, one.test(data.trim$comname, data.trim$FL_cm))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means < diff.means)
head(sig)
pvalue<-sig/1001 #pvalue=0.000. As this is less than 0.05, this means that Harbor seals consume significantly 
# smaller prey than gray seals.

mean <- data.frame(Means="Test statistic", vals = diff.means)

g1 <- ggplot(data=as.data.frame(perm.means), aes(perm.means)) + 
  geom_histogram(binwidth = 0.25, fill = barfill, colour = barlines) +
  xlab("Permuted Means") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Difference in Means") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
g1

# Printing histograms
grid.arrange(Pv_preylen, Hg_preylen, g1, nrow = 1, ncol = 3)

## RUN PERMUATION HYPOTHESIS TEST ON INDIVIDUAL PREY BIOMASS TO COMPLEMENT LENGTH

data<-data.trim

Pv_xprey_wgt.trim<- mean(data$FW_kg[data$comname == "Harbor Seal"])
Hg_xprey_wgt.trim<-mean(data$FW_kg[data$comname == "Gray Seal"])

Pv_mdprey_wgt.trim<- median(data$FW_kg[data$comname == "Harbor Seal"])
Hg_mdprey_wgt.trim<-median(data$FW_kg[data$comname == "Gray Seal"])

# First - plot histogram of Harbor Seal prey FW_kg consumed overall Pv samples

mean <- data.frame(Means="Test statistic", vals = Pv_xprey_wgt.trim)

Pv_preywgt <- ggplot(data=as.data.frame(data$FW_kg[data$comname == "Harbor Seal"]), 
                     aes(data$FW_kg[data$comname == "Harbor Seal"])) + 
  geom_histogram(binwidth = 0.01, fill = barfill, colour = barlines) + xlim(0,3.5) + ylim(0,200) +
  xlab("Prey weight (kg) consumed") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Harbor Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))

Pv_preywgt

# Plot histogram of Gray Seal prey FL_cm consumed overall Hg samples
mean <- data.frame(Means="Test statistic", vals = Hg_xprey_wgt.trim)

Hg_preywgt <- ggplot(data=as.data.frame(data$FW_kg[data$comname == "Gray Seal"]), 
                     aes(data$FW_kg[data$comname == "Gray Seal"])) + 
  geom_histogram(binwidth = 0.01, fill = barfill, colour = barlines) + xlim(0,3.5) + ylim(0,200) +
  xlab("Prey weight (kg) consumed") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Gray Seal") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
Hg_preywgt

# Printing histograms
grid.arrange(Pv_preywgt, Hg_preywgt, nrow = 1, ncol = 2)

#Pv_mean_meal_kgs<- mean(tagnum_mni_kgs$t_kgs[tagnum_mni_kgs$comname == "Harbor Seal"])
#Hg_mean_meal_kgs<-mean(tagnum_mni_kgs$t_kgs[tagnum_mni_kgs$comname == "Gray Seal"])


## Compute test statistics

diff.means <- mean(data$FW_kg[data$comname == "Harbor Seal"]) -
  mean(data$FW_kg[data$comname == "Gray Seal"])

diff.median <- median(data$FW_kg[data$comname == "Harbor Seal"]) -
  median(data$FW_kg[data$comname == "Gray Seal"])

#The test statistic is -0.062kg (-0.086 trimmed), which also indicates that harbor seals consumed smaller prey 
#on average 62 grams less than individual gray seal prey 
#over the time period 2004-2018.
#Median difference in prey weight = -0.045kg

# Create a function that randomly reassigns each observation to a different group 
# and then takes the mean difference between these new groups.

#grouping = comname
#variable = FW_kg or some other quantity

one.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  mean(variable[resampled.group == "Harbor Seal"]) - 
    mean(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(233)

data$resampled.group <- sample(data$comname)

rs.mean <- mean(data$FW_kg[data$resampled.group == "Harbor Seal"]) - 
  mean(data$FW_kg[data$resampled.group == "Gray Seal"])

head(data[ , c("comname", "resampled.group", "FW_kg")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.means <- replicate(1000, one.test(data$comname, data$FW_kg))

#Check whether your test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.means < diff.means)
head(sig)
pvalue<-sig/1001 #pvalue=0.000. As this is less than 0.05, this means that Harbor seals consume significantly 
# smaller prey than gray seals.

mean <- data.frame(Means="Test statistic", vals = diff.means)

g1 <- ggplot(data=as.data.frame(perm.means), aes(perm.means)) + 
  geom_histogram(binwidth = 0.005, fill = barfill, colour = barlines) +
  xlab("Difference in Means") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Permuted Means") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=mean, aes(xintercept=vals, linetype = Means, 
                            colour = Means), linewidth = 1, show.legend = FALSE) + 
  scale_color_manual(values=c("Test statistic" = line2))
g1

# Printing histograms
grid.arrange(Pv_preywgt, Hg_preywgt, g1, nrow = 1, ncol = 3)

# Run Permutation Test on median difference between weights for comparison with mean 

#grouping = comname
#variable = FW_kg or some other quantity

two.test <- function(grouping, variable) {
  resampled.group <- sample(grouping)
  median(variable[resampled.group == "Harbor Seal"]) - 
    median(variable[resampled.group == "Gray Seal"])
}

# Example of how resampling works:
set.seed(159)

data$resampled.group <- sample(data$comname)

rs.mean <- median(data$FW_kg[data$resampled.group == "Harbor Seal"]) - 
  median(data$FW_kg[data$resampled.group == "Gray Seal"])

head(data[ , c("comname", "resampled.group", "FW_kg")])

#Now repeat the permutation process 1,000 times to get a distribution of the mean difference of the permuted groups.
perm.medians <- replicate(1000, two.test(data$comname, data$FW_kg))

#Check whether your median test statistic is statistically different from 0, 
#we just check how it ranks compared to the permuted means:

sig <- sum(perm.medians < diff.median)
head(sig)
pvalue2<-sig/1001 #pvalue=0.000. As this is less than 0.05, this means that Harbor seals consume significantly 
# smaller prey than gray seals.

median <- data.frame(Median="Test statistic", vals = diff.median)

g2 <- ggplot(data=as.data.frame(perm.medians), aes(perm.medians)) + 
  geom_histogram(binwidth = 0.01, fill = barfill, colour = barlines) +
  xlab("Permuted Medians") +
  ylab("Frequency") +
  theme_bw() +
  ggtitle("Distribution of Permuted Median Diffs") + 
  theme(plot.title = element_text(lineheight=1.1, face="bold")) +
  geom_vline(data=median, aes(xintercept=vals, linetype = Median, 
                            colour = Median), linewidth = 1, show.legend = TRUE) + 
  scale_color_manual(values=c("Test statistic" = line2))
g2

  